@@ -6,5 +6,5 @@ AnyDict = Dict[Any, Any]
 def merge_dicts(*args: AnyDict) -> Dict:
     out = {}  # type: AnyDict
     for dct in args:
-        out = dict(**out, **dct)
+        out = {**out, **dct}
     return out
